@@ -1,6 +1,7 @@
 import csv
 import json
-from os import path
+from os import path, makedirs
+from os.path import basename
 from datetime import datetime
 
 from openpyxl import load_workbook
@@ -8,12 +9,13 @@ from openpyxl import load_workbook
 from resources import excel_headers
 from excel2meta_interface.utils import messages
 
+
 class Excel2Reference:
     start_time = datetime.now()
 
     def __init__(self, configuration_file="resources/excel2json_config.json"):
-        self.excel_location = "resources/datalineage/tmp"
-        self.excel_sheet = "excel format"
+        self.excel_location = "resources/datalineage/tmp/excels"
+        self.excel_sheet = "excel_file format"
         self.json_directory = "out/"
         self.json_file_prefix = "generated_"
         self.result = messages.message["ok"]
@@ -40,7 +42,7 @@ class Excel2Reference:
 
     def read_excel(self, file=None, sheet=None):
         """
-        read a sheet from a provided excel file
+        read a sheet from a provided excel_file file
         sets:
             self.work_book: a reference to the loaded work_book
             self.work_sheet: a reference to the loaded sheet
@@ -179,12 +181,12 @@ class Excel2Reference:
                                                            , name_column1="attribute_name"
                                                            , name_column2="attribute_description"
                                                            , give_list=True)
-        print("attributes:", attributes)
+        # print("attributes:", attributes)
         return attributes
 
     def get_dataset_info(self, datasets, source_or_target):
         info_datasets = []
-        print("source_or_target is:", source_or_target)
+        # print("source_or_target is:", source_or_target)
         ds_column = self.search_value_in_row_index(search_string=source_or_target)[0]
         description_column = self.search_value_in_row_index(search_string=excel_headers.source_dataset_description)[0]
         id_column = self.search_value_in_row_index(search_string=excel_headers.source_identifier)[0]
@@ -327,14 +329,14 @@ class Excel2Reference:
     def out_distinct(self, column_name=None, result_list=None):
         if column_name is None or result_list is None:
             return None
-        print(result_list)
+        # print(result_list)
         out_file = path.join(self.json_directory, self.json_file_prefix + column_name + ".csv")
         return self.write_list_to_file(out_file, result_list)
 
     def out_distinct_combined(self, filename, source_targets=None):
         if source_targets is None:
             return 6
-        print(source_targets)
+        # print(source_targets)
         # method will add extension
         out_file = path.join(self.json_directory, self.json_file_prefix + filename)
         return self.write_dict_to_file(out_file, source_targets)
@@ -459,7 +461,9 @@ class Excel2Reference:
     def main(self, excel=None):
         if self.result["code"] != "OK":
             return self.result
-
+        self.json_directory += basename(excel)
+        makedirs(self.json_directory, exist_ok=True)
+        print(self.json_directory)
         result = self.read_excel(excel, self.excel_sheet)
         if result["code"] != "OK":
             return result
