@@ -225,10 +225,18 @@ class JSON2EDCLineageFiles:
 
     def register_result(self, file, result):
         print("Result for file >%s< is >%s<" % (file, result["code"]))
-        filename = self.output_directory + self.start_time_formatted + "-" + __name__ + "-results.txt"
+        filename = self.output_directory + "results" + self.start_time_formatted + "-" + __name__ + ".txt"
         if path.exists(filename):
             append_or_write = "a"
         else:
             append_or_write = "w"
         with open(filename, append_or_write) as out:
             out.write(file + ": " + json.dumps(result) + "\n")
+        if result["code"] != "OK":
+            filename = self.output_directory + "errors-" + self.start_time_formatted + "-" + __name__ + ".txt"
+            if path.exists(filename):
+                append_or_write = "a"
+            else:
+                append_or_write = "w"
+            with open(filename, append_or_write) as out:
+                out.write(file + ": " + json.dumps(result) + "\n")
