@@ -98,4 +98,11 @@ message = {
         , "level": "ERROR"
         , "info": "none"
     }
+    ,
+    "entity_uuid_not_found": {
+        "code": "EMI-PRC-001"
+        , "message": "Could not find entity UUID"
+        , "level": "ERROR"
+        , "info": "none"
+    }
 }
